@@ -18,7 +18,6 @@ from redshift_client.id_objs import (
     TableId,
 )
 from redshift_client.sql_client.core import (
-    InvalidType,
     SqlClient,
 )
 from redshift_client.sql_client.query import (
@@ -36,7 +35,7 @@ _T = TypeVar("_T")
 def _assert_bool(raw: _T) -> bool:
     if isinstance(raw, bool):
         return raw
-    raise InvalidType("Expected bool")
+    raise TypeError("Expected bool")
 
 
 @dataclass(frozen=True)
@@ -44,12 +43,13 @@ class SchemaClient:
     _db_client: SqlClient
 
     def all_schemas(self) -> Cmd[FrozenSet[SchemaId]]:
-        stm = (
-            "SELECT s.nspname AS table_schema"
-            "FROM pg_catalog.pg_namespace s "
-            "JOIN pg_catalog.pg_user u ON u.usesysid = s.nspowner "
-            "ORDER BY table_schema"
+        _stm = (
+            "SELECT s.nspname AS table_schema",
+            "FROM pg_catalog.pg_namespace s",
+            "JOIN pg_catalog.pg_user u ON u.usesysid = s.nspowner",
+            "ORDER BY table_schema",
         )
+        stm = " ".join(_stm)
         return self._db_client.execute(
             new_query(stm), None
         ) + self._db_client.fetch_all().map(
@@ -59,10 +59,12 @@ class SchemaClient:
         )
 
     def table_ids(self, schema: SchemaId) -> Cmd[FrozenSet[TableId]]:
-        stm: str = (
-            "SELECT tables.table_name FROM information_schema.tables "
-            "WHERE table_schema = %(schema_name)s"
+        _stm = (
+            "SELECT tables.table_name FROM information_schema.tables",
+            "WHERE table_schema = %(schema_name)s",
         )
+        stm = " ".join(_stm)
+
         return self._db_client.execute(
             new_query(stm), FrozenDict({"schema_name": schema.name})
         ) + self._db_client.fetch_all().map(
@@ -72,17 +74,18 @@ class SchemaClient:
         )
 
     def exist(self, schema: SchemaId) -> Cmd[bool]:
-        stm: str = (
-            "SELECT EXISTS"
-            "(SELECT 1 FROM pg_namespace "
-            "WHERE nspname = %(schema_name)s)"
+        _stm = (
+            "SELECT EXISTS",
+            "(SELECT 1 FROM pg_namespace",
+            "WHERE nspname = %(schema_name)s)",
         )
+        stm = " ".join(_stm)
         return self._db_client.execute(
             new_query(stm), FrozenDict({"schema_name": schema.name})
         ) + self._db_client.fetch_one().map(
             lambda i: _assert_bool(i[0])
             if i is not None
-            else raise_exception(InvalidType("Expected not None"))
+            else raise_exception(TypeError("Expected not None"))
         )
 
     def delete(self, schema: SchemaId, cascade: bool) -> Cmd[None]:
